@@ -22,6 +22,7 @@ excel_dict = {"fake2excel": "https://www.bilibili.com/video/BV1wr4y1b7uk",
               "merge2sheet": "",
               "sheet2excel": "https://mp.weixin.qq.com/s/dAx6JEbj5OlVnCcxokCzTQ",
               "split_excel_by_column": "",
+              "excel2pdf": "https://www.zhihu.com/question/303009968/answer/2926093618",
               }
 image_dict = {"add_watermark": "https://www.bilibili.com/video/BV1jT411T7n9",
               "decode_qrcode": "https://mp.weixin.qq.com/s/Z_RcTRYxUFpCQBGpShO0ig",
@@ -43,7 +44,7 @@ pdf_dict = {"add_img_water": "",
             "pdf2imgs": "https://mp.weixin.qq.com/s/tvHZIBGcrMBLTLB4u23Mow",
             "txt2pdf": "", }
 ppt_dict = {"ppt2pdf": "https://mp.weixin.qq.com/s/T31F-U5AdDd3D-61b_K5Qg",
-            "ppt2img": "",
+            "ppt2img": "https://mp.weixin.qq.com/s/KtxI8H0RVJEnYtB18T6XiQ",
             }
 tools_dict = {"create_article": "https://mp.weixin.qq.com/s/guBtZHyUyybGNOqzZke1kQ",
               "lottery8ticket": "https://mp.weixin.qq.com/s/Q6JgW06hMUSik0DqGD0rOA",
